==> richfaces-showcase-4.5.3.Final-sources.jar: src/test/integration/org/richfaces/showcase/editor/page/AutosavingPage.java <==
/*******************************************************************************
 * JBoss, Home of Professional Open Source
 * Copyright 2010-2014, Red Hat, Inc. and individual contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 *******************************************************************************/
package org.richfaces.showcase.editor.page;

import org.openqa.selenium.WebElement;
import org.openqa.selenium.support.FindBy;
import org.richfaces.fragment.editor.RichFacesEditor;

public class AutosavingPage {

    @FindBy(css = ".example-cnt")
    private RichFacesEditor editor;

    @FindBy(css = ".rf-p-b")
    private WebElement outputFromEditor;

    public RichFacesEditor getEditor() {
        return editor;
    }

    public WebElement getOutputFromEditor() {
        return outputFromEditor;
    }

}

==> richfaces-showcase-4.5.10.Final-sources.jar: src/test/integration/org/richfaces/showcase/editor/page/AutosavingPage.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2010-2014, Red Hat, Inc. and individual contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.richfaces.showcase.editor.page;

import org.openqa.selenium.WebElement;
import org.openqa.selenium.support.FindBy;
import org.richfaces.fragment.editor.RichFacesEditor;

public class AutosavingPage {

    @FindBy(className = "rf-ed")
    private RichFacesEditor editor;

    @FindBy(className = "rf-p-b")
    private WebElement outputFromEditor;

    public RichFacesEditor getEditor() {
        return editor;
    }

    public WebElement getOutputFromEditor() {
        return outputFromEditor;
    }

}
